@@ -1,4 +1,5 @@
-from collections import OrderedDict
+import re
+from textwrap import dedent
 
 from graphql_relay import to_global_id
 
@@ -6,7 +7,7 @@ from ...types import ObjectType, Schema, String
 from ..node import Node, is_node
 
 
-class SharedNodeFields(object):
+class SharedNodeFields:
 
     shared = String()
     something_else = String()
@@ -54,6 +55,7 @@ def test_node_good():
     assert "id" in MyNode._meta.fields
     assert is_node(MyNode)
     assert not is_node(object)
+    assert not is_node("node")
 
 
 def test_node_query():
@@ -70,23 +72,33 @@ def test_subclassed_node_query():
         % to_global_id("MyOtherNode", 1)
     )
     assert not executed.errors
-    assert executed.data == OrderedDict(
-        {
-            "node": OrderedDict(
-                [
-                    ("shared", "1"),
-                    ("extraField", "extra field info."),
-                    ("somethingElse", "----"),
-                ]
-            )
+    assert executed.data == {
+        "node": {
+            "shared": "1",
+            "extraField": "extra field info.",
+            "somethingElse": "----",
         }
-    )
+    }
 
 
 def test_node_requesting_non_node():
     executed = schema.execute(
         '{ node(id:"%s") { __typename } } ' % Node.to_global_id("RootQuery", 1)
     )
+    assert executed.errors
+    assert re.match(
+        r"ObjectType .* does not implement the .* interface.",
+        executed.errors[0].message,
+    )
+    assert executed.data == {"node": None}
+
+
+def test_node_requesting_unknown_type():
+    executed = schema.execute(
+        '{ node(id:"%s") { __typename } } ' % Node.to_global_id("UnknownType", 1)
+    )
+    assert executed.errors
+    assert re.match(r"Relay Node .* not found in schema", executed.errors[0].message)
     assert executed.data == {"node": None}
 
 
@@ -94,7 +106,8 @@ def test_node_query_incorrect_id():
     executed = schema.execute(
         '{ node(id:"%s") { ... on MyNode { name } } }' % "something:2"
     )
-    assert not executed.errors
+    assert executed.errors
+    assert re.match(r"Unable to parse global ID .*", executed.errors[0].message)
     assert executed.data == {"node": None}
 
 
@@ -110,6 +123,17 @@ def test_node_field_custom():
     assert node_field.node_type == Node
 
 
+def test_node_field_args():
+    field_args = {
+        "name": "my_custom_name",
+        "description": "my_custom_description",
+        "deprecation_reason": "my_custom_deprecation_reason",
+    }
+    node_field = Node.Field(**field_args)
+    for field_arg, value in field_args.items():
+        assert getattr(node_field, field_arg) == value
+
+
 def test_node_field_only_type():
     executed = schema.execute(
         '{ onlyNode(id:"%s") { __typename, name } } ' % Node.to_global_id("MyNode", 1)
@@ -124,7 +148,7 @@ def test_node_field_only_type_wrong():
         % Node.to_global_id("MyOtherNode", 1)
     )
     assert len(executed.errors) == 1
-    assert str(executed.errors[0]) == "Must receive a MyNode id."
+    assert str(executed.errors[0]).startswith("Must receive a MyNode id.")
     assert executed.data == {"onlyNode": None}
 
 
@@ -143,39 +167,54 @@ def test_node_field_only_lazy_type_wrong():
         % Node.to_global_id("MyOtherNode", 1)
     )
     assert len(executed.errors) == 1
-    assert str(executed.errors[0]) == "Must receive a MyNode id."
+    assert str(executed.errors[0]).startswith("Must receive a MyNode id.")
     assert executed.data == {"onlyNodeLazy": None}
 
 
 def test_str_schema():
     assert (
-        str(schema)
-        == """
-schema {
-  query: RootQuery
-}
+        str(schema).strip()
+        == dedent(
+            '''
+        schema {
+          query: RootQuery
+        }
 
-type MyNode implements Node {
-  id: ID!
-  name: String
-}
+        type MyNode implements Node {
+          """The ID of the object"""
+          id: ID!
+          name: String
+        }
 
-type MyOtherNode implements Node {
-  id: ID!
-  shared: String
-  somethingElse: String
-  extraField: String
-}
+        """An object with an ID"""
+        interface Node {
+          """The ID of the object"""
+          id: ID!
+        }
 
-interface Node {
-  id: ID!
-}
+        type MyOtherNode implements Node {
+          """The ID of the object"""
+          id: ID!
+          shared: String
+          somethingElse: String
+          extraField: String
+        }
 
-type RootQuery {
-  first: String
-  node(id: ID!): Node
-  onlyNode(id: ID!): MyNode
-  onlyNodeLazy(id: ID!): MyNode
-}
-""".lstrip()
+        type RootQuery {
+          first: String
+          node(
+            """The ID of the object"""
+            id: ID!
+          ): Node
+          onlyNode(
+            """The ID of the object"""
+            id: ID!
+          ): MyNode
+          onlyNodeLazy(
+            """The ID of the object"""
+            id: ID!
+          ): MyNode
+        }
+        '''
+        ).strip()
     )
